## License
This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details

## v1.0.1 (2024-07-20)
- Fixed: Bug when import `validator`.

## v1.0.2 (2024-07-20)
- Fixed: Libary deprecated.

## v1.0.3 (2024-07-20)
- Fixed: Libary deprecated.

## v1.0.4 (2024-07-20)
- Fixed: Libary deprecated.

## v1.0.5 (2024-07-20)
- Fixed: Libary deprecated.

## v1.0.6 (2024-07-20)
- Fixed: Libary deprecated.

## v1.0.7 (2024-07-20)
- Fixed: Libary deprecated.

## v1.0.8 (2024-07-20)
- Fixed: Libary deprecated.

## v1.0.9 (2024-07-20)
- Fixed: Libary deprecated.

## v1.1.0 (2024-07-20)
- Fixed: Bug connect database to Odoo.

## v1.2.0 (2024-07-20)
- Fixed: Bug connect database to Odoo.

## v1.2.1 (2024-07-20)
- Fixed: Bug unique and exist rule.

## v1.2.2 (2024-07-20)
- Fixed: Error when connect use postgres.

## v1.3.2 (2024-07-20)
- Refinement: Groups Inheritance Rule Class.

## v1.4.2 (2024-07-20)
- Feature: Rule can accept function as argument, Rule Chaning

## v1.4.3 (2024-07-20)
- Fixed: Error when validation failed

## v1.4.3 (2024-07-20)
- Fixed: Sometimes rule failed

## v1.4.4 (2024-07-20)
- Fixed: Sometimes rule failed